==> open-cluster-management-operator-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MultiClusterHubSpecFluent<A extends MultiClusterHubSpecFluent<A>> extends Fluent<A>{
  public String getAvailabilityConfig();
  public A withAvailabilityConfig(String availabilityConfig);
  public Boolean hasAvailabilityConfig();
  public String getCustomCAConfigmap();
  public A withCustomCAConfigmap(String customCAConfigmap);
  public Boolean hasCustomCAConfigmap();
  public Boolean getDisableHubSelfManagement();
  public A withDisableHubSelfManagement(Boolean disableHubSelfManagement);
  public Boolean hasDisableHubSelfManagement();
  public Boolean getDisableUpdateClusterImageSets();
  public A withDisableUpdateClusterImageSets(Boolean disableUpdateClusterImageSets);
  public Boolean hasDisableUpdateClusterImageSets();
  public Boolean getEnableClusterBackup();
  public A withEnableClusterBackup(Boolean enableClusterBackup);
  public Boolean hasEnableClusterBackup();
  public Boolean getEnableClusterProxyAddon();
  public A withEnableClusterProxyAddon(Boolean enableClusterProxyAddon);
  public Boolean hasEnableClusterProxyAddon();
  
  /**
   * This method has been deprecated, please use method buildHive instead.
   * @return The buildable object.
   */
  @Deprecated
  public HiveConfigSpec getHive();
  public HiveConfigSpec buildHive();
  public A withHive(HiveConfigSpec hive);
  public Boolean hasHive();
  public MultiClusterHubSpecFluent.HiveNested<A> withNewHive();
  public MultiClusterHubSpecFluent.HiveNested<A> withNewHiveLike(HiveConfigSpec item);
  public MultiClusterHubSpecFluent.HiveNested<A> editHive();
  public MultiClusterHubSpecFluent.HiveNested<A> editOrNewHive();
  public MultiClusterHubSpecFluent.HiveNested<A> editOrNewHiveLike(HiveConfigSpec item);
  public String getImagePullSecret();
  public A withImagePullSecret(String imagePullSecret);
  public Boolean hasImagePullSecret();
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressSpec getIngress();
  public IngressSpec buildIngress();
  public A withIngress(IngressSpec ingress);
  public Boolean hasIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> withNewIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> withNewIngressLike(IngressSpec item);
  public MultiClusterHubSpecFluent.IngressNested<A> editIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> editOrNewIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> editOrNewIngressLike(IngressSpec item);
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public Overrides getOverrides();
  public Overrides buildOverrides();
  public A withOverrides(Overrides overrides);
  public Boolean hasOverrides();
  public A withNewOverrides(String imagePullPolicy);
  public MultiClusterHubSpecFluent.OverridesNested<A> withNewOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> withNewOverridesLike(Overrides item);
  public MultiClusterHubSpecFluent.OverridesNested<A> editOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> editOrNewOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> editOrNewOverridesLike(Overrides item);
  public Boolean getSeparateCertificateManagement();
  public A withSeparateCertificateManagement(Boolean separateCertificateManagement);
  public Boolean hasSeparateCertificateManagement();
  public A withDisableHubSelfManagement();
  public A withDisableUpdateClusterImageSets();
  public A withEnableClusterBackup();
  public A withEnableClusterProxyAddon();
  public A withSeparateCertificateManagement();
  public interface HiveNested<N> extends Nested<N>,HiveConfigSpecFluent<MultiClusterHubSpecFluent.HiveNested<N>>{
    public N and();
    public N endHive();
    
  }
  public interface IngressNested<N> extends Nested<N>,IngressSpecFluent<MultiClusterHubSpecFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  public interface OverridesNested<N> extends Nested<N>,OverridesFluent<MultiClusterHubSpecFluent.OverridesNested<N>>{
    public N and();
    public N endOverrides();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface MultiClusterHubSpecFluent<A extends MultiClusterHubSpecFluent<A>> extends Fluent<A>{
  public String getAvailabilityConfig();
  public A withAvailabilityConfig(String availabilityConfig);
  public Boolean hasAvailabilityConfig();
  public String getCustomCAConfigmap();
  public A withCustomCAConfigmap(String customCAConfigmap);
  public Boolean hasCustomCAConfigmap();
  public Boolean getDisableHubSelfManagement();
  public A withDisableHubSelfManagement(Boolean disableHubSelfManagement);
  public Boolean hasDisableHubSelfManagement();
  public Boolean getDisableUpdateClusterImageSets();
  public A withDisableUpdateClusterImageSets(Boolean disableUpdateClusterImageSets);
  public Boolean hasDisableUpdateClusterImageSets();
  public Boolean getEnableClusterBackup();
  public A withEnableClusterBackup(Boolean enableClusterBackup);
  public Boolean hasEnableClusterBackup();
  public Boolean getEnableClusterProxyAddon();
  public A withEnableClusterProxyAddon(Boolean enableClusterProxyAddon);
  public Boolean hasEnableClusterProxyAddon();
  
  /**
   * This method has been deprecated, please use method buildHive instead.
   * @return The buildable object.
   */
  @Deprecated
  public HiveConfigSpec getHive();
  public HiveConfigSpec buildHive();
  public A withHive(HiveConfigSpec hive);
  public Boolean hasHive();
  public MultiClusterHubSpecFluent.HiveNested<A> withNewHive();
  public MultiClusterHubSpecFluent.HiveNested<A> withNewHiveLike(HiveConfigSpec item);
  public MultiClusterHubSpecFluent.HiveNested<A> editHive();
  public MultiClusterHubSpecFluent.HiveNested<A> editOrNewHive();
  public MultiClusterHubSpecFluent.HiveNested<A> editOrNewHiveLike(HiveConfigSpec item);
  public String getImagePullSecret();
  public A withImagePullSecret(String imagePullSecret);
  public Boolean hasImagePullSecret();
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressSpec getIngress();
  public IngressSpec buildIngress();
  public A withIngress(IngressSpec ingress);
  public Boolean hasIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> withNewIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> withNewIngressLike(IngressSpec item);
  public MultiClusterHubSpecFluent.IngressNested<A> editIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> editOrNewIngress();
  public MultiClusterHubSpecFluent.IngressNested<A> editOrNewIngressLike(IngressSpec item);
  public A addToNodeSelector(String key,String value);
  public A addToNodeSelector(Map<String,String> map);
  public A removeFromNodeSelector(String key);
  public A removeFromNodeSelector(Map<String,String> map);
  public Map<String,String> getNodeSelector();
  public <K,V>A withNodeSelector(Map<String,String> nodeSelector);
  public Boolean hasNodeSelector();
  
  /**
   * This method has been deprecated, please use method buildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public Overrides getOverrides();
  public Overrides buildOverrides();
  public A withOverrides(Overrides overrides);
  public Boolean hasOverrides();
  public A withNewOverrides(String imagePullPolicy);
  public MultiClusterHubSpecFluent.OverridesNested<A> withNewOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> withNewOverridesLike(Overrides item);
  public MultiClusterHubSpecFluent.OverridesNested<A> editOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> editOrNewOverrides();
  public MultiClusterHubSpecFluent.OverridesNested<A> editOrNewOverridesLike(Overrides item);
  public Boolean getSeparateCertificateManagement();
  public A withSeparateCertificateManagement(Boolean separateCertificateManagement);
  public Boolean hasSeparateCertificateManagement();
  public A withDisableHubSelfManagement();
  public A withDisableUpdateClusterImageSets();
  public A withEnableClusterBackup();
  public A withEnableClusterProxyAddon();
  public A withSeparateCertificateManagement();
  public interface HiveNested<N> extends Nested<N>,HiveConfigSpecFluent<MultiClusterHubSpecFluent.HiveNested<N>>{
    public N and();
    public N endHive();
    
  }
  public interface IngressNested<N> extends Nested<N>,IngressSpecFluent<MultiClusterHubSpecFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  public interface OverridesNested<N> extends Nested<N>,OverridesFluent<MultiClusterHubSpecFluent.OverridesNested<N>>{
    public N and();
    public N endOverrides();
    
  }
  
}
